@@ -15,9 +15,11 @@
 
 from opentelemetry.sdk._logs._internal import (
     LogData,
+    LogDroppedAttributesWarning,
     Logger,
     LoggerProvider,
     LoggingHandler,
+    LogLimits,
     LogRecord,
     LogRecordProcessor,
 )
@@ -27,6 +29,8 @@ __all__ = [
     "Logger",
     "LoggerProvider",
     "LoggingHandler",
+    "LogLimits",
     "LogRecord",
     "LogRecordProcessor",
+    "LogDroppedAttributesWarning",
 ]
