@@ -23,7 +23,8 @@ This package implements `OpenTelemetry Resources
     these attributes can be included in the Resource.*
 
 Resource objects are created with `Resource.create`, which accepts attributes
-(key-values). Resources should NOT be created via constructor, and working with
+(key-values). Resources should NOT be created via constructor except by `ResourceDetector`
+instances which can't use `Resource.create` to avoid infinite loops. Working with
 `Resource` objects should only be done via the Resource API methods. Resource
 attributes can also be passed at process invocation in the
 :envvar:`OTEL_RESOURCE_ATTRIBUTES` environment variable. You should register
@@ -53,13 +54,14 @@ Note that the OpenTelemetry project documents certain `"standard attributes"
 <https://github.com/open-telemetry/opentelemetry-specification/blob/main/specification/resource/semantic_conventions/README.md>`_
 that have prescribed semantic meanings, for example ``service.name`` in the
 above example.
- """
+"""
 
 import abc
 import concurrent.futures
 import logging
 import os
 import platform
+import socket
 import sys
 import typing
 from json import dumps
@@ -83,7 +85,7 @@ psutil: Optional[ModuleType] = None
 try:
     import psutil as psutil_module
 
-    pustil = psutil_module
+    psutil = psutil_module
 except ImportError:
     pass
 
@@ -105,6 +107,7 @@ FAAS_ID = ResourceAttributes.FAAS_ID
 FAAS_VERSION = ResourceAttributes.FAAS_VERSION
 FAAS_INSTANCE = ResourceAttributes.FAAS_INSTANCE
 HOST_NAME = ResourceAttributes.HOST_NAME
+HOST_ARCH = ResourceAttributes.HOST_ARCH
 HOST_TYPE = ResourceAttributes.HOST_TYPE
 HOST_IMAGE_NAME = ResourceAttributes.HOST_IMAGE_NAME
 HOST_IMAGE_ID = ResourceAttributes.HOST_IMAGE_ID
@@ -173,6 +176,8 @@ class Resource:
     ) -> "Resource":
         """Creates a new `Resource` from attributes.
 
+        `ResourceDetector` instances should not call this method.
+
         Args:
             attributes: Optional zero or more key-value pairs.
             schema_url: Optional URL pointing to the schema
@@ -198,16 +203,23 @@ class Resource:
 
         resource_detector: str
         for resource_detector in otel_experimental_resource_detectors:
-            resource_detectors.append(
-                next(
-                    iter(
-                        entry_points(
-                            group="opentelemetry_resource_detector",
-                            name=resource_detector.strip(),
-                        )  # type: ignore
-                    )
-                ).load()()
-            )
+            try:
+                resource_detectors.append(
+                    next(
+                        iter(
+                            entry_points(
+                                group="opentelemetry_resource_detector",
+                                name=resource_detector.strip(),
+                            )  # type: ignore
+                        )
+                    ).load()()
+                )
+            except Exception:  # pylint: disable=broad-exception-caught
+                logger.exception(
+                    "Failed to load resource detector '%s', skipping",
+                    resource_detector,
+                )
+                continue
         resource = get_aggregated_resources(
             resource_detectors, _DEFAULT_RESOURCE
         ).merge(Resource(attributes, schema_url))
@@ -285,7 +297,7 @@ class Resource:
             f"{dumps(self._attributes.copy(), sort_keys=True)}|{self._schema_url}"  # type: ignore
         )
 
-    def to_json(self, indent: int = 4) -> str:
+    def to_json(self, indent: Optional[int] = 4) -> str:
         attributes: MutableMapping[str, AttributeValue] = dict(
             self._attributes
         )
@@ -314,13 +326,13 @@ class ResourceDetector(abc.ABC):
 
     @abc.abstractmethod
     def detect(self) -> "Resource":
+        """Don't call `Resource.create` here to avoid an infinite loop, instead instantiate `Resource` directly"""
         raise NotImplementedError()
 
 
 class OTELResourceDetector(ResourceDetector):
     # pylint: disable=no-self-use
     def detect(self) -> "Resource":
-
         env_resources_items = environ.get(OTEL_RESOURCE_ATTRIBUTES)
         env_resource_map = {}
 
@@ -471,6 +483,20 @@ class OsResourceDetector(ResourceDetector):
         )
 
 
+class _HostResourceDetector(ResourceDetector):
+    """
+    The HostResourceDetector detects the hostname and architecture attributes.
+    """
+
+    def detect(self) -> "Resource":
+        return Resource(
+            {
+                HOST_NAME: socket.gethostname(),
+                HOST_ARCH: platform.machine(),
+            }
+        )
+
+
 def get_aggregated_resources(
     detectors: typing.List["ResourceDetector"],
     initial_resource: typing.Optional[Resource] = None,
