@@ -30,6 +30,7 @@ from typing import (
     Dict,
     Iterator,
     List,
+    Mapping,
     MutableMapping,
     Optional,
     Sequence,
@@ -482,7 +483,7 @@ class ReadableSpan:
     def instrumentation_scope(self) -> Optional[InstrumentationScope]:
         return self._instrumentation_scope
 
-    def to_json(self, indent: int = 4):
+    def to_json(self, indent: Optional[int] = 4):
         parent_id = None
         if self.parent is not None:
             parent_id = f"0x{trace_api.format_span_id(self.parent.span_id)}"
@@ -619,7 +620,6 @@ class SpanLimits:
         max_attribute_length: Optional[int] = None,
         max_span_attribute_length: Optional[int] = None,
     ):
-
         # span events and links count
         self.max_events = self._from_env_if_absent(
             max_events,
@@ -692,7 +692,7 @@ class SpanLimits:
         if value == cls.UNSET:
             return None
 
-        err_msg = "{0} must be a non-negative integer but got {}"
+        err_msg = "{} must be a non-negative integer but got {}"
 
         # if no value is provided for the limit, try to load it from env
         if value is None:
@@ -726,12 +726,10 @@ _UnsetLimits = SpanLimits(
 )
 
 # not removed for backward compat. please use SpanLimits instead.
-SPAN_ATTRIBUTE_COUNT_LIMIT = (
-    SpanLimits._from_env_if_absent(  # pylint: disable=protected-access
-        None,
-        OTEL_SPAN_ATTRIBUTE_COUNT_LIMIT,
-        _DEFAULT_OTEL_SPAN_ATTRIBUTE_COUNT_LIMIT,
-    )
+SPAN_ATTRIBUTE_COUNT_LIMIT = SpanLimits._from_env_if_absent(  # pylint: disable=protected-access
+    None,
+    OTEL_SPAN_ATTRIBUTE_COUNT_LIMIT,
+    _DEFAULT_OTEL_SPAN_ATTRIBUTE_COUNT_LIMIT,
 )
 
 
@@ -845,7 +843,7 @@ class Span(trace_api.Span, ReadableSpan):
         return self._context
 
     def set_attributes(
-        self, attributes: Dict[str, types.AttributeValue]
+        self, attributes: Mapping[str, types.AttributeValue]
     ) -> None:
         with self._lock:
             if self._end_time is not None:
@@ -890,7 +888,6 @@ class Span(trace_api.Span, ReadableSpan):
         context: SpanContext,
         attributes: types.Attributes = None,
     ) -> None:
-
         if not _is_valid_link(context, attributes):
             return
 
@@ -1118,7 +1115,6 @@ class Tracer(trace_api.Tracer):
         record_exception: bool = True,
         set_status_on_exception: bool = True,
     ) -> trace_api.Span:
-
         parent_span_context = trace_api.get_current_span(
             context
         ).get_span_context()
@@ -1233,7 +1229,6 @@ class TracerProvider(trace_api.TracerProvider):
         attributes: typing.Optional[types.Attributes] = None,
     ) -> "trace_api.Tracer":
         if self._disabled:
-            logger.warning("SDK is disabled.")
             return NoOpTracer()
         if not instrumenting_module_name:  # Reject empty strings too.
             instrumenting_module_name = ""
@@ -1282,7 +1277,7 @@ class TracerProvider(trace_api.TracerProvider):
         # SynchronousMultiSpanProcessor and ConcurrentMultiSpanProcessor.
         self._active_span_processor.add_span_processor(span_processor)
 
-    def shutdown(self):
+    def shutdown(self) -> None:
         """Shut down the span processors added to the tracer provider."""
         self._active_span_processor.shutdown()
         if self._atexit_handler is not None:
