@@ -13,14 +13,19 @@
 # limitations under the License.
 
 # pylint: disable=protected-access
+import gc
 import logging
 import multiprocessing
 import os
 import time
 import unittest
+import weakref
 from concurrent.futures import ThreadPoolExecutor
+from sys import version_info
 from unittest.mock import Mock, patch
 
+from pytest import mark
+
 from opentelemetry._logs import SeverityNumber
 from opentelemetry.sdk import trace
 from opentelemetry.sdk._logs import (
@@ -48,6 +53,11 @@ from opentelemetry.test.concurrency_test import ConcurrencyTestBase
 from opentelemetry.trace import TraceFlags
 from opentelemetry.trace.span import INVALID_SPAN_CONTEXT
 
+EMPTY_LOG = LogData(
+    log_record=LogRecord(),
+    instrumentation_scope=InstrumentationScope("example", "example"),
+)
+
 
 class TestSimpleLogRecordProcessor(unittest.TestCase):
     def test_simple_log_record_processor_default_level(self):
@@ -71,6 +81,9 @@ class TestSimpleLogRecordProcessor(unittest.TestCase):
         self.assertEqual(
             warning_log_record.severity_number, SeverityNumber.WARN
         )
+        self.assertEqual(
+            finished_logs[0].instrumentation_scope.name, "default_level"
+        )
 
     def test_simple_log_record_processor_custom_level(self):
         exporter = InMemoryLogExporter()
@@ -104,6 +117,12 @@ class TestSimpleLogRecordProcessor(unittest.TestCase):
         self.assertEqual(
             fatal_log_record.severity_number, SeverityNumber.FATAL
         )
+        self.assertEqual(
+            finished_logs[0].instrumentation_scope.name, "custom_level"
+        )
+        self.assertEqual(
+            finished_logs[1].instrumentation_scope.name, "custom_level"
+        )
 
     def test_simple_log_record_processor_trace_correlation(self):
         exporter = InMemoryLogExporter()
@@ -129,6 +148,9 @@ class TestSimpleLogRecordProcessor(unittest.TestCase):
         self.assertEqual(
             log_record.trace_flags, INVALID_SPAN_CONTEXT.trace_flags
         )
+        self.assertEqual(
+            finished_logs[0].instrumentation_scope.name, "trace_correlation"
+        )
         exporter.clear()
 
         tracer = trace.TracerProvider().get_tracer(__name__)
@@ -140,6 +162,10 @@ class TestSimpleLogRecordProcessor(unittest.TestCase):
             self.assertEqual(log_record.body, "Critical message within span")
             self.assertEqual(log_record.severity_text, "CRITICAL")
             self.assertEqual(log_record.severity_number, SeverityNumber.FATAL)
+            self.assertEqual(
+                finished_logs[0].instrumentation_scope.name,
+                "trace_correlation",
+            )
             span_context = span.get_span_context()
             self.assertEqual(log_record.trace_id, span_context.trace_id)
             self.assertEqual(log_record.span_id, span_context.span_id)
@@ -166,6 +192,9 @@ class TestSimpleLogRecordProcessor(unittest.TestCase):
         self.assertEqual(
             warning_log_record.severity_number, SeverityNumber.WARN
         )
+        self.assertEqual(
+            finished_logs[0].instrumentation_scope.name, "shutdown"
+        )
         exporter.clear()
         logger_provider.shutdown()
         with self.assertLogs(level=logging.WARNING):
@@ -206,9 +235,108 @@ class TestSimpleLogRecordProcessor(unittest.TestCase):
             for item in finished_logs
         ]
         self.assertEqual(expected, emitted)
+        for item in finished_logs:
+            self.assertEqual(
+                item.instrumentation_scope.name, "different_msg_types"
+            )
+
+    def test_simple_log_record_processor_custom_single_obj(self):
+        """
+        Tests that special-case handling for logging a single non-string object
+        is correctly applied.
+        """
+        exporter = InMemoryLogExporter()
+        log_record_processor = BatchLogRecordProcessor(exporter)
+
+        provider = LoggerProvider()
+        provider.add_log_record_processor(log_record_processor)
+
+        logger = logging.getLogger("single_obj")
+        logger.addHandler(LoggingHandler(logger_provider=provider))
+
+        # NOTE: the behaviour of `record.getMessage` is detailed in the
+        # `logging.Logger.debug` documentation:
+        # > The msg is the message format string, and the args are the arguments
+        # > which are merged into msg using the string formatting operator. [...]
+        # > No % formatting operation is performed on msg when no args are supplied.
+
+        # This test uses the presence of '%s' in the first arg to determine if
+        # formatting was applied
+
+        # string msg with no args - getMessage bypasses formatting and sets the string directly
+        logger.warning("a string with a percent-s: %s")
+        # string msg with args - getMessage formats args into the msg
+        logger.warning("a string with a percent-s: %s", "and arg")
+        # non-string msg with args - getMessage stringifies msg and formats args into it
+        logger.warning(["a non-string with a percent-s", "%s"], "and arg")
+        # non-string msg with no args:
+        #  - normally getMessage would stringify the object and bypass formatting
+        #  - SPECIAL CASE: bypass stringification as well to keep the raw object
+        logger.warning(["a non-string with a percent-s", "%s"])
+        log_record_processor.shutdown()
+
+        finished_logs = exporter.get_finished_logs()
+        expected = [
+            ("a string with a percent-s: %s"),
+            ("a string with a percent-s: and arg"),
+            ("['a non-string with a percent-s', 'and arg']"),
+            (["a non-string with a percent-s", "%s"]),
+        ]
+        for emitted, expected in zip(finished_logs, expected):
+            self.assertEqual(emitted.log_record.body, expected)
+            self.assertEqual(emitted.instrumentation_scope.name, "single_obj")
+
+    def test_simple_log_record_processor_different_msg_types_with_formatter(
+        self,
+    ):
+        exporter = InMemoryLogExporter()
+        log_record_processor = BatchLogRecordProcessor(exporter)
+
+        provider = LoggerProvider()
+        provider.add_log_record_processor(log_record_processor)
+
+        logger = logging.getLogger("different_msg_types")
+        handler = LoggingHandler(logger_provider=provider)
+        handler.setFormatter(
+            logging.Formatter("%(name)s - %(levelname)s - %(message)s")
+        )
+        logger.addHandler(handler)
+
+        logger.warning("warning message: %s", "possible upcoming heatwave")
+        logger.error("Very high rise in temperatures across the globe")
+        logger.critical("Temperature hits high 420 C in Hyderabad")
+        logger.warning(["list", "of", "strings"])
+        logger.error({"key": "value"})
+        log_record_processor.shutdown()
+
+        finished_logs = exporter.get_finished_logs()
+        expected = [
+            (
+                "different_msg_types - WARNING - warning message: possible upcoming heatwave",
+                "WARN",
+            ),
+            (
+                "different_msg_types - ERROR - Very high rise in temperatures across the globe",
+                "ERROR",
+            ),
+            (
+                "different_msg_types - CRITICAL - Temperature hits high 420 C in Hyderabad",
+                "CRITICAL",
+            ),
+            (
+                "different_msg_types - WARNING - ['list', 'of', 'strings']",
+                "WARN",
+            ),
+            ("different_msg_types - ERROR - {'key': 'value'}", "ERROR"),
+        ]
+        emitted = [
+            (item.log_record.body, item.log_record.severity_text)
+            for item in finished_logs
+        ]
+        self.assertEqual(expected, emitted)
 
 
-class TestBatchLogRecordProcessor(ConcurrencyTestBase):
+class TestBatchLogRecordProcessor(unittest.TestCase):
     def test_emit_call_log_record(self):
         exporter = InMemoryLogExporter()
         log_record_processor = Mock(wraps=BatchLogRecordProcessor(exporter))
@@ -222,6 +350,39 @@ class TestBatchLogRecordProcessor(ConcurrencyTestBase):
         logger.error("error")
         self.assertEqual(log_record_processor.emit.call_count, 1)
 
+    @mark.skipif(
+        version_info < (3, 10),
+        reason="assertNoLogs only exists in python 3.10+.",
+    )
+    def test_logging_lib_not_invoked_in_batch_log_record_emit(self):  # pylint: disable=no-self-use
+        # See https://github.com/open-telemetry/opentelemetry-python/issues/4261
+        exporter = Mock()
+        processor = BatchLogRecordProcessor(exporter)
+        logger_provider = LoggerProvider(
+            resource=SDKResource.create(
+                {
+                    "service.name": "shoppingcart",
+                    "service.instance.id": "instance-12",
+                }
+            ),
+        )
+        logger_provider.add_log_record_processor(processor)
+        handler = LoggingHandler(
+            level=logging.INFO, logger_provider=logger_provider
+        )
+        sdk_logger = logging.getLogger("opentelemetry.sdk")
+        # Attach OTLP handler to SDK logger
+        sdk_logger.addHandler(handler)
+        # If `emit` calls logging.log then this test will throw a maximum recursion depth exceeded exception and fail.
+        try:
+            with self.assertNoLogs(sdk_logger, logging.NOTSET):
+                processor.emit(EMPTY_LOG)
+            processor.shutdown()
+            with self.assertNoLogs(sdk_logger, logging.NOTSET):
+                processor.emit(EMPTY_LOG)
+        finally:
+            sdk_logger.removeHandler(handler)
+
     def test_args(self):
         exporter = InMemoryLogExporter()
         log_record_processor = BatchLogRecordProcessor(
@@ -233,7 +394,7 @@ class TestBatchLogRecordProcessor(ConcurrencyTestBase):
         )
         self.assertEqual(log_record_processor._exporter, exporter)
         self.assertEqual(log_record_processor._max_queue_size, 1024)
-        self.assertEqual(log_record_processor._schedule_delay_millis, 2500)
+        self.assertEqual(log_record_processor._schedule_delay, 2.5)
         self.assertEqual(log_record_processor._max_export_batch_size, 256)
         self.assertEqual(log_record_processor._export_timeout_millis, 15000)
 
@@ -251,7 +412,7 @@ class TestBatchLogRecordProcessor(ConcurrencyTestBase):
         log_record_processor = BatchLogRecordProcessor(exporter)
         self.assertEqual(log_record_processor._exporter, exporter)
         self.assertEqual(log_record_processor._max_queue_size, 1024)
-        self.assertEqual(log_record_processor._schedule_delay_millis, 2500)
+        self.assertEqual(log_record_processor._schedule_delay, 2.5)
         self.assertEqual(log_record_processor._max_export_batch_size, 256)
         self.assertEqual(log_record_processor._export_timeout_millis, 15000)
 
@@ -260,7 +421,7 @@ class TestBatchLogRecordProcessor(ConcurrencyTestBase):
         log_record_processor = BatchLogRecordProcessor(exporter)
         self.assertEqual(log_record_processor._exporter, exporter)
         self.assertEqual(log_record_processor._max_queue_size, 2048)
-        self.assertEqual(log_record_processor._schedule_delay_millis, 5000)
+        self.assertEqual(log_record_processor._schedule_delay, 5)
         self.assertEqual(log_record_processor._max_export_batch_size, 512)
         self.assertEqual(log_record_processor._export_timeout_millis, 30000)
 
@@ -280,7 +441,7 @@ class TestBatchLogRecordProcessor(ConcurrencyTestBase):
         _logger.disabled = False
         self.assertEqual(log_record_processor._exporter, exporter)
         self.assertEqual(log_record_processor._max_queue_size, 2048)
-        self.assertEqual(log_record_processor._schedule_delay_millis, 5000)
+        self.assertEqual(log_record_processor._schedule_delay, 5)
         self.assertEqual(log_record_processor._max_export_batch_size, 512)
         self.assertEqual(log_record_processor._export_timeout_millis, 30000)
 
@@ -295,7 +456,7 @@ class TestBatchLogRecordProcessor(ConcurrencyTestBase):
         )
         self.assertEqual(log_record_processor._exporter, exporter)
         self.assertEqual(log_record_processor._max_queue_size, 2048)
-        self.assertEqual(log_record_processor._schedule_delay_millis, 5000)
+        self.assertEqual(log_record_processor._schedule_delay, 5)
         self.assertEqual(log_record_processor._max_export_batch_size, 512)
         self.assertEqual(log_record_processor._export_timeout_millis, 30000)
 
@@ -345,99 +506,82 @@ class TestBatchLogRecordProcessor(ConcurrencyTestBase):
             max_export_batch_size=101,
         )
 
-    def test_shutdown(self):
-        exporter = InMemoryLogExporter()
-        log_record_processor = BatchLogRecordProcessor(exporter)
+    def test_logs_exported_once_batch_size_reached(self):
+        exporter = Mock()
+        log_record_processor = BatchLogRecordProcessor(
+            exporter=exporter,
+            max_queue_size=15,
+            max_export_batch_size=15,
+            # Will not reach this during the test, this sleep should be interrupted when batch size is reached.
+            schedule_delay_millis=30000,
+        )
+        before_export = time.time_ns()
+        for _ in range(15):
+            log_record_processor.emit(EMPTY_LOG)
+        # Wait a bit for the worker thread to wake up and call export.
+        time.sleep(0.1)
+        exporter.export.assert_called_once()
+        after_export = time.time_ns()
+        # Shows the worker's 30 second sleep was interrupted within a second.
+        self.assertLess(after_export - before_export, 1e9)
 
-        provider = LoggerProvider()
-        provider.add_log_record_processor(log_record_processor)
-
-        logger = logging.getLogger("shutdown")
-        logger.addHandler(LoggingHandler(logger_provider=provider))
-
-        with self.assertLogs(level=logging.WARNING):
-            logger.warning("warning message: %s", "possible upcoming heatwave")
-        with self.assertLogs(level=logging.WARNING):
-            logger.error("Very high rise in temperatures across the globe")
-        with self.assertLogs(level=logging.WARNING):
-            logger.critical("Temperature hits high 420 C in Hyderabad")
+    # pylint: disable=no-self-use
+    def test_logs_exported_once_schedule_delay_reached(self):
+        exporter = Mock()
+        log_record_processor = BatchLogRecordProcessor(
+            exporter=exporter,
+            max_queue_size=15,
+            max_export_batch_size=15,
+            schedule_delay_millis=100,
+        )
+        log_record_processor.emit(EMPTY_LOG)
+        time.sleep(0.2)
+        exporter.export.assert_called_once_with([EMPTY_LOG])
 
+    def test_logs_flushed_before_shutdown_and_dropped_after_shutdown(self):
+        exporter = Mock()
+        log_record_processor = BatchLogRecordProcessor(
+            exporter=exporter,
+            # Neither of these thresholds should be hit before test ends.
+            max_queue_size=15,
+            max_export_batch_size=15,
+            schedule_delay_millis=30000,
+        )
+        # This log should be flushed because it was written before shutdown.
+        log_record_processor.emit(EMPTY_LOG)
         log_record_processor.shutdown()
+        exporter.export.assert_called_once_with([EMPTY_LOG])
         self.assertTrue(exporter._stopped)
 
-        finished_logs = exporter.get_finished_logs()
-        expected = [
-            ("warning message: possible upcoming heatwave", "WARN"),
-            ("Very high rise in temperatures across the globe", "ERROR"),
-            (
-                "Temperature hits high 420 C in Hyderabad",
-                "CRITICAL",
-            ),
-        ]
-        emitted = [
-            (item.log_record.body, item.log_record.severity_text)
-            for item in finished_logs
-        ]
-        self.assertEqual(expected, emitted)
+        exporter.export.assert_called_once()
 
-    def test_force_flush(self):
-        exporter = InMemoryLogExporter()
-        log_record_processor = BatchLogRecordProcessor(exporter)
-
-        provider = LoggerProvider()
-        provider.add_log_record_processor(log_record_processor)
-
-        logger = logging.getLogger("force_flush")
-        logger.propagate = False
-        logger.addHandler(LoggingHandler(logger_provider=provider))
-
-        logger.critical("Earth is burning")
+    # pylint: disable=no-self-use
+    def test_force_flush_flushes_logs(self):
+        exporter = Mock()
+        log_record_processor = BatchLogRecordProcessor(
+            exporter=exporter,
+            # Neither of these thresholds should be hit before test ends.
+            max_queue_size=15,
+            max_export_batch_size=15,
+            schedule_delay_millis=30000,
+        )
+        for _ in range(10):
+            log_record_processor.emit(EMPTY_LOG)
         log_record_processor.force_flush()
-        finished_logs = exporter.get_finished_logs()
-        self.assertEqual(len(finished_logs), 1)
-        log_record = finished_logs[0].log_record
-        self.assertEqual(log_record.body, "Earth is burning")
-        self.assertEqual(log_record.severity_number, SeverityNumber.FATAL)
-
-    def test_log_record_processor_too_many_logs(self):
-        exporter = InMemoryLogExporter()
-        log_record_processor = BatchLogRecordProcessor(exporter)
-
-        provider = LoggerProvider()
-        provider.add_log_record_processor(log_record_processor)
-
-        logger = logging.getLogger("many_logs")
-        logger.propagate = False
-        logger.addHandler(LoggingHandler(logger_provider=provider))
-
-        for log_no in range(1000):
-            logger.critical("Log no: %s", log_no)
-
-        self.assertTrue(log_record_processor.force_flush())
-        finised_logs = exporter.get_finished_logs()
-        self.assertEqual(len(finised_logs), 1000)
+        exporter.export.assert_called_once_with([EMPTY_LOG for _ in range(10)])
 
     def test_with_multiple_threads(self):
         exporter = InMemoryLogExporter()
         log_record_processor = BatchLogRecordProcessor(exporter)
 
-        provider = LoggerProvider()
-        provider.add_log_record_processor(log_record_processor)
-
-        logger = logging.getLogger("threads")
-        logger.propagate = False
-        logger.addHandler(LoggingHandler(logger_provider=provider))
-
         def bulk_log_and_flush(num_logs):
             for _ in range(num_logs):
-                logger.critical("Critical message")
-            self.assertTrue(log_record_processor.force_flush())
+                log_record_processor.emit(EMPTY_LOG)
+            log_record_processor.force_flush()
 
         with ThreadPoolExecutor(max_workers=69) as executor:
-            futures = []
             for idx in range(69):
-                future = executor.submit(bulk_log_and_flush, idx + 1)
-                futures.append(future)
+                executor.submit(bulk_log_and_flush, idx + 1)
 
             executor.shutdown()
 
@@ -448,49 +592,80 @@ class TestBatchLogRecordProcessor(ConcurrencyTestBase):
         hasattr(os, "fork"),
         "needs *nix",
     )
-    def test_batch_log_record_processor_fork(self):
-        # pylint: disable=invalid-name
+    def test_batch_log_record_processor_fork_clears_logs_from_child(self):
         exporter = InMemoryLogExporter()
         log_record_processor = BatchLogRecordProcessor(
             exporter,
             max_export_batch_size=64,
-            schedule_delay_millis=10,
+            schedule_delay_millis=30000,
         )
-        provider = LoggerProvider()
-        provider.add_log_record_processor(log_record_processor)
-
-        logger = logging.getLogger("test-fork")
-        logger.propagate = False
-        logger.addHandler(LoggingHandler(logger_provider=provider))
-
-        logger.critical("yolo")
-        time.sleep(0.5)  # give some time for the exporter to upload
-
-        self.assertTrue(log_record_processor.force_flush())
-        self.assertEqual(len(exporter.get_finished_logs()), 1)
-        exporter.clear()
+        # These logs should be flushed only from the parent process.
+        # _at_fork_reinit should be called in the child process, to
+        # clear these logs in the child process.
+        for _ in range(10):
+            log_record_processor.emit(EMPTY_LOG)
 
+        # The below test also needs this, but it can only be set once.
         multiprocessing.set_start_method("fork")
 
+        def child(conn):
+            log_record_processor.force_flush()
+            logs = exporter.get_finished_logs()
+            conn.send(len(logs) == 0)
+            conn.close()
+
+        parent_conn, child_conn = multiprocessing.Pipe()
+        process = multiprocessing.Process(target=child, args=(child_conn,))
+        process.start()
+        self.assertTrue(parent_conn.recv())
+        process.join()
+        log_record_processor.force_flush()
+        self.assertTrue(len(exporter.get_finished_logs()) == 10)
+
+    @unittest.skipUnless(
+        hasattr(os, "fork"),
+        "needs *nix",
+    )
+    def test_batch_log_record_processor_fork_doesnot_deadlock(self):
+        exporter = InMemoryLogExporter()
+        log_record_processor = BatchLogRecordProcessor(
+            exporter,
+            max_export_batch_size=64,
+            schedule_delay_millis=30000,
+        )
+
         def child(conn):
             def _target():
-                logger.critical("Critical message child")
-
-            self.run_with_many_threads(_target, 100)
-
-            time.sleep(0.5)
+                log_record_processor.emit(EMPTY_LOG)
 
+            ConcurrencyTestBase.run_with_many_threads(_target, 100)
+            log_record_processor.force_flush()
             logs = exporter.get_finished_logs()
             conn.send(len(logs) == 100)
             conn.close()
 
         parent_conn, child_conn = multiprocessing.Pipe()
-        p = multiprocessing.Process(target=child, args=(child_conn,))
-        p.start()
+        process = multiprocessing.Process(target=child, args=(child_conn,))
+        process.start()
         self.assertTrue(parent_conn.recv())
-        p.join()
+        process.join()
 
-        log_record_processor.shutdown()
+    def test_batch_log_record_processor_gc(self):
+        # Given a BatchLogRecordProcessor
+        exporter = InMemoryLogExporter()
+        processor = BatchLogRecordProcessor(exporter)
+        weak_ref = weakref.ref(processor)
+        processor.shutdown()
+
+        # When the processor is garbage collected
+        del processor
+        gc.collect()
+
+        # Then the reference to the processor should no longer exist
+        self.assertIsNone(
+            weak_ref(),
+            "The BatchLogRecordProcessor object created by this test wasn't garbage collected",
+        )
 
 
 class TestConsoleLogExporter(unittest.TestCase):
@@ -534,11 +709,6 @@ class TestConsoleLogExporter(unittest.TestCase):
 
         mock_stdout = Mock()
         exporter = ConsoleLogExporter(out=mock_stdout, formatter=formatter)
-        log_data = LogData(
-            log_record=LogRecord(),
-            instrumentation_scope=InstrumentationScope(
-                "first_name", "first_version"
-            ),
-        )
-        exporter.export([log_data])
+        exporter.export([EMPTY_LOG])
+
         mock_stdout.write.assert_called_once_with(mock_record_str)
