@@ -11,9 +11,11 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
+
 import logging
+import os
 import unittest
-from unittest.mock import Mock
+from unittest.mock import Mock, patch
 
 from opentelemetry._logs import NoOpLoggerProvider, SeverityNumber
 from opentelemetry._logs import get_logger as APIGetLogger
@@ -25,7 +27,8 @@ from opentelemetry.sdk._logs import (
     LoggingHandler,
     LogRecordProcessor,
 )
-from opentelemetry.semconv.trace import SpanAttributes
+from opentelemetry.semconv._incubating.attributes import code_attributes
+from opentelemetry.semconv.attributes import exception_attributes
 from opentelemetry.trace import INVALID_SPAN_CONTEXT
 
 
@@ -125,17 +128,19 @@ class TestLoggingHandler(unittest.TestCase):
         self.assertEqual(len(log_record.attributes), 4)
         self.assertEqual(log_record.attributes["http.status_code"], 200)
         self.assertTrue(
-            log_record.attributes[SpanAttributes.CODE_FILEPATH].endswith(
+            log_record.attributes[code_attributes.CODE_FILE_PATH].endswith(
                 "test_handler.py"
             )
         )
         self.assertEqual(
-            log_record.attributes[SpanAttributes.CODE_FUNCTION],
+            log_record.attributes[code_attributes.CODE_FUNCTION_NAME],
             "test_log_record_user_attributes",
         )
         # The line of the log statement is not a constant (changing tests may change that),
         # so only check that the attribute is present.
-        self.assertTrue(SpanAttributes.CODE_LINENO in log_record.attributes)
+        self.assertTrue(
+            code_attributes.CODE_LINE_NUMBER in log_record.attributes
+        )
         self.assertTrue(isinstance(log_record.attributes, BoundedAttributes))
 
     def test_log_record_exception(self):
@@ -151,17 +156,18 @@ class TestLoggingHandler(unittest.TestCase):
         log_record = processor.get_log_record(0)
 
         self.assertIsNotNone(log_record)
+        self.assertTrue(isinstance(log_record.body, str))
         self.assertEqual(log_record.body, "Zero Division Error")
         self.assertEqual(
-            log_record.attributes[SpanAttributes.EXCEPTION_TYPE],
+            log_record.attributes[exception_attributes.EXCEPTION_TYPE],
             ZeroDivisionError.__name__,
         )
         self.assertEqual(
-            log_record.attributes[SpanAttributes.EXCEPTION_MESSAGE],
+            log_record.attributes[exception_attributes.EXCEPTION_MESSAGE],
             "division by zero",
         )
         stack_trace = log_record.attributes[
-            SpanAttributes.EXCEPTION_STACKTRACE
+            exception_attributes.EXCEPTION_STACKTRACE
         ]
         self.assertIsInstance(stack_trace, str)
         self.assertTrue("Traceback" in stack_trace)
@@ -186,15 +192,15 @@ class TestLoggingHandler(unittest.TestCase):
         self.assertIsNotNone(log_record)
         self.assertEqual(log_record.body, "Zero Division Error")
         self.assertEqual(
-            log_record.attributes[SpanAttributes.EXCEPTION_TYPE],
+            log_record.attributes[exception_attributes.EXCEPTION_TYPE],
             ZeroDivisionError.__name__,
         )
         self.assertEqual(
-            log_record.attributes[SpanAttributes.EXCEPTION_MESSAGE],
+            log_record.attributes[exception_attributes.EXCEPTION_MESSAGE],
             "division by zero",
         )
         stack_trace = log_record.attributes[
-            SpanAttributes.EXCEPTION_STACKTRACE
+            exception_attributes.EXCEPTION_STACKTRACE
         ]
         self.assertIsInstance(stack_trace, str)
         self.assertTrue("Traceback" in stack_trace)
@@ -216,13 +222,49 @@ class TestLoggingHandler(unittest.TestCase):
 
         self.assertIsNotNone(log_record)
         self.assertEqual(log_record.body, "Zero Division Error")
-        self.assertNotIn(SpanAttributes.EXCEPTION_TYPE, log_record.attributes)
         self.assertNotIn(
-            SpanAttributes.EXCEPTION_MESSAGE, log_record.attributes
+            exception_attributes.EXCEPTION_TYPE, log_record.attributes
         )
         self.assertNotIn(
-            SpanAttributes.EXCEPTION_STACKTRACE, log_record.attributes
+            exception_attributes.EXCEPTION_MESSAGE, log_record.attributes
         )
+        self.assertNotIn(
+            exception_attributes.EXCEPTION_STACKTRACE, log_record.attributes
+        )
+
+    def test_log_record_exception_with_object_payload(self):
+        processor, logger = set_up_test_logging(logging.ERROR)
+
+        class CustomException(Exception):
+            def __str__(self):
+                return "CustomException stringified"
+
+        try:
+            raise CustomException("CustomException message")
+        except CustomException as exception:
+            with self.assertLogs(level=logging.ERROR):
+                logger.exception(exception)
+
+        log_record = processor.get_log_record(0)
+
+        self.assertIsNotNone(log_record)
+        self.assertTrue(isinstance(log_record.body, str))
+        self.assertEqual(log_record.body, "CustomException stringified")
+        self.assertEqual(
+            log_record.attributes[exception_attributes.EXCEPTION_TYPE],
+            CustomException.__name__,
+        )
+        self.assertEqual(
+            log_record.attributes[exception_attributes.EXCEPTION_MESSAGE],
+            "CustomException message",
+        )
+        stack_trace = log_record.attributes[
+            exception_attributes.EXCEPTION_STACKTRACE
+        ]
+        self.assertIsInstance(stack_trace, str)
+        self.assertTrue("Traceback" in stack_trace)
+        self.assertTrue("CustomException" in stack_trace)
+        self.assertTrue(__file__ in stack_trace)
 
     def test_log_record_trace_correlation(self):
         processor, logger = set_up_test_logging(logging.WARNING)
@@ -242,13 +284,64 @@ class TestLoggingHandler(unittest.TestCase):
             self.assertEqual(log_record.span_id, span_context.span_id)
             self.assertEqual(log_record.trace_flags, span_context.trace_flags)
 
+    def test_warning_without_formatter(self):
+        processor, logger = set_up_test_logging(logging.WARNING)
+        logger.warning("Test message")
 
-def set_up_test_logging(level):
+        log_record = processor.get_log_record(0)
+        self.assertEqual(log_record.body, "Test message")
+
+    def test_exception_without_formatter(self):
+        processor, logger = set_up_test_logging(logging.WARNING)
+        logger.exception("Test exception")
+
+        log_record = processor.get_log_record(0)
+        self.assertEqual(log_record.body, "Test exception")
+
+    def test_warning_with_formatter(self):
+        processor, logger = set_up_test_logging(
+            logging.WARNING,
+            formatter=logging.Formatter(
+                "%(name)s - %(levelname)s - %(message)s"
+            ),
+        )
+        logger.warning("Test message")
+
+        log_record = processor.get_log_record(0)
+        self.assertEqual(log_record.body, "foo - WARNING - Test message")
+
+    def test_log_body_is_always_string_with_formatter(self):
+        processor, logger = set_up_test_logging(
+            logging.WARNING,
+            formatter=logging.Formatter(
+                "%(name)s - %(levelname)s - %(message)s"
+            ),
+        )
+        logger.warning(["something", "of", "note"])
+
+        log_record = processor.get_log_record(0)
+        self.assertIsInstance(log_record.body, str)
+
+    @patch.dict(os.environ, {"OTEL_SDK_DISABLED": "true"})
+    def test_handler_root_logger_with_disabled_sdk_does_not_go_into_recursion_error(
+        self,
+    ):
+        processor, logger = set_up_test_logging(
+            logging.NOTSET, root_logger=True
+        )
+        logger.warning("hello")
+
+        self.assertEqual(processor.emit_count(), 0)
+
+
+def set_up_test_logging(level, formatter=None, root_logger=False):
     logger_provider = LoggerProvider()
     processor = FakeProcessor()
     logger_provider.add_log_record_processor(processor)
-    logger = logging.getLogger("foo")
+    logger = logging.getLogger(None if root_logger else "foo")
     handler = LoggingHandler(level=level, logger_provider=logger_provider)
+    if formatter:
+        handler.setFormatter(formatter)
     logger.addHandler(handler)
     return processor, logger
 
