@@ -13,11 +13,13 @@
 # limitations under the License.
 # type: ignore
 # pylint: skip-file
+from __future__ import annotations
 
+import logging
 from logging import WARNING, getLogger
 from os import environ
-from typing import Dict, Iterable, Optional, Sequence
-from unittest import TestCase
+from typing import Iterable, Optional, Sequence
+from unittest import TestCase, mock
 from unittest.mock import Mock, patch
 
 from pytest import raises
@@ -43,6 +45,7 @@ from opentelemetry.sdk._configuration import (
     _OTelSDKConfigurator,
 )
 from opentelemetry.sdk._logs import LoggingHandler
+from opentelemetry.sdk._logs._internal.export import LogExporter
 from opentelemetry.sdk._logs.export import ConsoleLogExporter
 from opentelemetry.sdk.environment_variables import (
     OTEL_TRACES_SAMPLER,
@@ -136,10 +139,11 @@ class DummyMetricReader(MetricReader):
     def __init__(
         self,
         exporter: MetricExporter,
-        preferred_temporality: Dict[type, AggregationTemporality] = None,
-        preferred_aggregation: Dict[type, Aggregation] = None,
-        export_interval_millis: Optional[float] = None,
-        export_timeout_millis: Optional[float] = None,
+        preferred_temporality: dict[type, AggregationTemporality]
+        | None = None,
+        preferred_aggregation: dict[type, Aggregation] | None = None,
+        export_interval_millis: float | None = None,
+        export_timeout_millis: float | None = None,
     ) -> None:
         super().__init__(
             preferred_temporality=preferred_temporality,
@@ -201,7 +205,7 @@ class OTLPSpanExporter:
     pass
 
 
-class DummyOTLPLogExporter:
+class DummyOTLPLogExporter(LogExporter):
     def __init__(self, *args, **kwargs):
         self.export_called = False
 
@@ -250,13 +254,13 @@ class CustomRatioSampler(TraceIdRatioBased):
 
     def should_sample(
         self,
-        parent_context: Optional["Context"],
+        parent_context: "Context" | None,
         trace_id: int,
         name: str,
-        kind: SpanKind = None,
+        kind: SpanKind | None = None,
         attributes: Attributes = None,
-        links: Sequence[Link] = None,
-        trace_state: TraceState = None,
+        links: Sequence[Link] | None = None,
+        trace_state: TraceState | None = None,
     ) -> "SamplingResult":
         return SamplingResult(
             Decision.RECORD_AND_SAMPLE,
@@ -586,14 +590,32 @@ class TestLoggingInit(TestCase):
             "opentelemetry.sdk._configuration.set_logger_provider"
         )
 
+        self.event_logger_provider_instance_mock = Mock()
+        self.event_logger_provider_patch = patch(
+            "opentelemetry.sdk._configuration.EventLoggerProvider",
+            return_value=self.event_logger_provider_instance_mock,
+        )
+        self.set_event_logger_provider_patch = patch(
+            "opentelemetry.sdk._configuration.set_event_logger_provider"
+        )
+
         self.processor_mock = self.processor_patch.start()
         self.provider_mock = self.provider_patch.start()
         self.set_provider_mock = self.set_provider_patch.start()
 
+        self.event_logger_provider_mock = (
+            self.event_logger_provider_patch.start()
+        )
+        self.set_event_logger_provider_mock = (
+            self.set_event_logger_provider_patch.start()
+        )
+
     def tearDown(self):
         self.processor_patch.stop()
         self.set_provider_patch.stop()
         self.provider_patch.stop()
+        self.event_logger_provider_patch.stop()
+        self.set_event_logger_provider_patch.stop()
         root_logger = getLogger("root")
         root_logger.handlers = [
             handler
@@ -616,6 +638,12 @@ class TestLoggingInit(TestCase):
             provider.resource.attributes.get("telemetry.auto.version"),
             "auto-version",
         )
+        self.event_logger_provider_mock.assert_called_once_with(
+            logger_provider=provider
+        )
+        self.set_event_logger_provider_mock.assert_called_once_with(
+            self.event_logger_provider_instance_mock
+        )
 
     @patch.dict(
         environ,
@@ -639,6 +667,32 @@ class TestLoggingInit(TestCase):
         getLogger(__name__).error("hello")
         self.assertTrue(provider.processor.exporter.export_called)
 
+    @patch.dict(
+        environ,
+        {"OTEL_RESOURCE_ATTRIBUTES": "service.name=otlp-service"},
+    )
+    def test_logging_init_exporter_without_handler_setup(self):
+        resource = Resource.create({})
+        _init_logging(
+            {"otlp": DummyOTLPLogExporter},
+            resource=resource,
+            setup_logging_handler=False,
+        )
+        self.assertEqual(self.set_provider_mock.call_count, 1)
+        provider = self.set_provider_mock.call_args[0][0]
+        self.assertIsInstance(provider, DummyLoggerProvider)
+        self.assertIsInstance(provider.resource, Resource)
+        self.assertEqual(
+            provider.resource.attributes.get("service.name"),
+            "otlp-service",
+        )
+        self.assertIsInstance(provider.processor, DummyLogRecordProcessor)
+        self.assertIsInstance(
+            provider.processor.exporter, DummyOTLPLogExporter
+        )
+        getLogger(__name__).error("hello")
+        self.assertFalse(provider.processor.exporter.export_called)
+
     @patch.dict(
         environ,
         {"OTEL_RESOURCE_ATTRIBUTES": "service.name=otlp-service"},
@@ -647,8 +701,8 @@ class TestLoggingInit(TestCase):
     @patch("opentelemetry.sdk._configuration._init_logging")
     def test_logging_init_disable_default(self, logging_mock, tracing_mock):
         _initialize_components(auto_instrumentation_version="auto-version")
-        self.assertEqual(logging_mock.call_count, 0)
         self.assertEqual(tracing_mock.call_count, 1)
+        logging_mock.assert_called_once_with(mock.ANY, mock.ANY, False)
 
     @patch.dict(
         environ,
@@ -662,7 +716,7 @@ class TestLoggingInit(TestCase):
     def test_logging_init_enable_env(self, logging_mock, tracing_mock):
         with self.assertLogs(level=WARNING):
             _initialize_components(auto_instrumentation_version="auto-version")
-        self.assertEqual(logging_mock.call_count, 1)
+        logging_mock.assert_called_once_with(mock.ANY, mock.ANY, True)
         self.assertEqual(tracing_mock.call_count, 1)
 
     @patch.dict(
@@ -744,7 +798,7 @@ class TestLoggingInit(TestCase):
                 "custom.key.2": "pass-in-value-2",
             },
             "id_generator": "TEST_GENERATOR",
-            "logging_enabled": True,
+            "setup_logging_handler": True,
         }
         _initialize_components(**kwargs)
 
@@ -786,8 +840,63 @@ class TestLoggingInit(TestCase):
         logging_mock.assert_called_once_with(
             "TEST_LOG_EXPORTERS_DICT",
             "TEST_RESOURCE",
+            True,
         )
 
+    def test_basicConfig_works_with_otel_handler(self):
+        with ClearLoggingHandlers():
+            _init_logging(
+                {"otlp": DummyOTLPLogExporter},
+                Resource.create({}),
+                setup_logging_handler=True,
+            )
+
+            logging.basicConfig(level=logging.INFO)
+
+            root_logger = logging.getLogger()
+            stream_handlers = [
+                h
+                for h in root_logger.handlers
+                if isinstance(h, logging.StreamHandler)
+            ]
+            self.assertEqual(
+                len(stream_handlers),
+                1,
+                "basicConfig should add a StreamHandler even when OTel handler exists",
+            )
+
+    def test_basicConfig_preserves_otel_handler(self):
+        with ClearLoggingHandlers():
+            _init_logging(
+                {"otlp": DummyOTLPLogExporter},
+                Resource.create({}),
+                setup_logging_handler=True,
+            )
+
+            root_logger = logging.getLogger()
+            self.assertEqual(
+                len(root_logger.handlers),
+                1,
+                "Should be exactly one OpenTelemetry LoggingHandler",
+            )
+            handler = root_logger.handlers[0]
+            self.assertIsInstance(handler, LoggingHandler)
+
+            logging.basicConfig()
+
+            self.assertGreater(len(root_logger.handlers), 1)
+
+            logging_handlers = [
+                h
+                for h in root_logger.handlers
+                if isinstance(h, LoggingHandler)
+            ]
+            self.assertEqual(
+                len(logging_handlers),
+                1,
+                "Should still have exactly one OpenTelemetry LoggingHandler",
+            )
+
 
 class TestMetricsInit(TestCase):
     def setUp(self):
@@ -985,7 +1094,6 @@ class TestImportConfigComponents(TestCase):
     def test__import_config_components_missing_entry_point(
         self, mock_entry_points
     ):
-
         with raises(RuntimeError) as error:
             _import_config_components(["a", "b", "c"], "name")
         self.assertEqual(
@@ -999,7 +1107,6 @@ class TestImportConfigComponents(TestCase):
     def test__import_config_components_missing_component(
         self, mock_entry_points
     ):
-
         with raises(RuntimeError) as error:
             _import_config_components(["a", "b", "c"], "name")
         self.assertEqual(
@@ -1025,3 +1132,40 @@ class TestConfigurator(TestCase):
             "sampler": "TEST_SAMPLER",
         }
         mock_init_comp.assert_called_once_with(**kwargs)
+
+
+class ClearLoggingHandlers:
+    def __init__(self):
+        self.root_logger = getLogger()
+        self.original_handlers = None
+
+    def __enter__(self):
+        self.original_handlers = self.root_logger.handlers[:]
+        self.root_logger.handlers = []
+        return self
+
+    def __exit__(self, exc_type, exc_val, exc_tb):
+        self.root_logger.handlers = []
+        for handler in self.original_handlers:
+            self.root_logger.addHandler(handler)
+
+
+class TestClearLoggingHandlers(TestCase):
+    def test_preserves_handlers(self):
+        root_logger = getLogger()
+        initial_handlers = root_logger.handlers[:]
+
+        test_handler = logging.StreamHandler()
+        root_logger.addHandler(test_handler)
+        expected_handlers = initial_handlers + [test_handler]
+
+        with ClearLoggingHandlers():
+            self.assertEqual(len(root_logger.handlers), 0)
+            temp_handler = logging.StreamHandler()
+            root_logger.addHandler(temp_handler)
+
+        self.assertEqual(len(root_logger.handlers), len(expected_handlers))
+        for h1, h2 in zip(root_logger.handlers, expected_handlers):
+            self.assertIs(h1, h2)
+
+        root_logger.removeHandler(test_handler)
