@@ -12,11 +12,13 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import gc
 import multiprocessing
 import os
 import threading
 import time
 import unittest
+import weakref
 from concurrent.futures import ThreadPoolExecutor
 from logging import WARNING
 from platform import python_implementation, system
@@ -179,7 +181,6 @@ class TestBatchSpanProcessor(ConcurrencyTestBase):
         },
     )
     def test_args_env_var(self):
-
         batch_span_processor = export.BatchSpanProcessor(
             MySpanExporter(destination=[])
         )
@@ -190,7 +191,6 @@ class TestBatchSpanProcessor(ConcurrencyTestBase):
         self.assertEqual(batch_span_processor.export_timeout_millis, 4)
 
     def test_args_env_var_defaults(self):
-
         batch_span_processor = export.BatchSpanProcessor(
             MySpanExporter(destination=[])
         )
@@ -210,7 +210,6 @@ class TestBatchSpanProcessor(ConcurrencyTestBase):
         },
     )
     def test_args_env_var_value_error(self):
-
         logger.disabled = True
         batch_span_processor = export.BatchSpanProcessor(
             MySpanExporter(destination=[])
@@ -588,6 +587,23 @@ class TestBatchSpanProcessor(ConcurrencyTestBase):
             max_export_batch_size=512,
         )
 
+    def test_batch_span_processor_gc(self):
+        # Given a BatchSpanProcessor
+        exporter = MySpanExporter(destination=[])
+        processor = export.BatchSpanProcessor(exporter)
+        weak_ref = weakref.ref(processor)
+        processor.shutdown()
+
+        # When the processor is garbage collected
+        del processor
+        gc.collect()
+
+        # Then the reference to the processor should no longer exist
+        self.assertIsNone(
+            weak_ref(),
+            "The BatchSpanProcessor object created by this test wasn't garbage collected",
+        )
+
 
 class TestConsoleSpanExporter(unittest.TestCase):
     def test_export(self):  # pylint: disable=no-self-use
